@@ -2,7 +2,7 @@ from .__version__ import __description__, __title__, __version__
 from ._api import delete, get, head, options, patch, post, put, request, stream
 from ._auth import Auth, BasicAuth, DigestAuth
 from ._client import AsyncClient, Client
-from ._config import Limits, PoolLimits, Proxy, Timeout, create_ssl_context
+from ._config import Limits, Proxy, Timeout, create_ssl_context
 from ._exceptions import (
     CloseError,
     ConnectError,
@@ -14,14 +14,12 @@ from ._exceptions import (
     InvalidURL,
     LocalProtocolError,
     NetworkError,
-    NotRedirectResponse,
     PoolTimeout,
     ProtocolError,
     ProxyError,
     ReadError,
     ReadTimeout,
     RemoteProtocolError,
-    RequestBodyUnavailable,
     RequestError,
     RequestNotRead,
     ResponseClosed,
@@ -38,74 +36,72 @@ from ._exceptions import (
 from ._models import URL, Cookies, Headers, QueryParams, Request, Response
 from ._status_codes import StatusCode, codes
 from ._transports.asgi import ASGITransport
-from ._transports.urllib3 import URLLib3ProxyTransport, URLLib3Transport
 from ._transports.wsgi import WSGITransport
 
 __all__ = [
     "__description__",
     "__title__",
     "__version__",
-    "delete",
-    "get",
-    "head",
-    "options",
-    "patch",
-    "post",
-    "patch",
-    "put",
-    "request",
-    "stream",
-    "codes",
     "ASGITransport",
     "AsyncClient",
     "Auth",
     "BasicAuth",
     "Client",
-    "DigestAuth",
-    "Limits",
-    "PoolLimits",
-    "Proxy",
-    "Timeout",
-    "create_ssl_context",
     "CloseError",
+    "codes",
     "ConnectError",
     "ConnectTimeout",
     "CookieConflict",
+    "Cookies",
+    "create_ssl_context",
     "DecodingError",
+    "delete",
+    "DigestAuth",
+    "get",
+    "head",
+    "Headers",
     "HTTPError",
     "HTTPStatusError",
     "InvalidURL",
-    "UnsupportedProtocol",
+    "Limits",
     "LocalProtocolError",
-    "RemoteProtocolError",
     "NetworkError",
-    "NotRedirectResponse",
+    "options",
+    "patch",
     "PoolTimeout",
+    "post",
     "ProtocolError",
+    "Proxy",
+    "ProxyError",
+    "put",
+    "QueryParams",
     "ReadError",
     "ReadTimeout",
+    "RemoteProtocolError",
+    "request",
+    "Request",
     "RequestError",
-    "RequestBodyUnavailable",
+    "RequestNotRead",
+    "Response",
     "ResponseClosed",
     "ResponseNotRead",
-    "RequestNotRead",
     "StatusCode",
+    "stream",
     "StreamConsumed",
     "StreamError",
-    "ProxyError",
+    "Timeout",
     "TimeoutException",
     "TooManyRedirects",
     "TransportError",
+    "UnsupportedProtocol",
+    "URL",
     "WriteError",
     "WriteTimeout",
-    "URL",
-    "URLLib3Transport",
-    "URLLib3ProxyTransport",
-    "Cookies",
-    "Headers",
-    "QueryParams",
-    "Request",
-    "Response",
-    "DigestAuth",
     "WSGITransport",
 ]
+
+
+__locals = locals()
+for __name in __all__:
+    if not __name.startswith("__"):
+        setattr(__locals[__name], "__module__", "httpx")  # noqa
